Contributors
------------

- Wojciech Lichota
- Rok Garbas
- Harald Friessnegger
- Héctor Velarde
- JeanMichel FRANCOIS
- Juan A. Diaz
- Franco Pellegrini
- Guido Stevens
- Andre Nogueira
- Philip Bauer
